@@ -4,14 +4,14 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 require XSLoader;
 XSLoader::load("Basic::Types::XS", $VERSION);
 
 sub import {
 	my ($caller, $pkg, @export) = (scalar caller(), @_);
-	install($caller, @export);
+	_install($caller, @export);
 }
 
 1;
@@ -24,7 +24,7 @@ Basic::Types::XS - The great new Basic::Types::XS!
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
@@ -39,12 +39,28 @@ Version 0.02
 
 =head1 EXPORT
 
+=head2 Defined
+
 =head2 Str
 
 =head2 Num
 
+=head2 Int
+
+=head2 Ref
+
+=head2 ScalarRef
+
+=head2 ArrayRef
+
+=head2 HashRef
+
 =cut
 
+=head1 METHODS
+
+=head2 validate
+
 =head1 AUTHOR
 
 LNATION, C<< <email at lnation.org> >>
